==> 2.1.0.tar.gz: lxqt-powermanagement-2.1.0/src/translations/lxqt-powermanagement_ca.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>BatteryHelper</name>
    <message>
        <location filename="../batteryhelper.cpp" line="44"/>
        <source>Stable</source>
        <translation>Estable</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="46"/>
        <source>Discharging</source>
        <translation>S&apos;està descarregant</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="48"/>
        <source>Fully charged</source>
        <translation>Completament carregada</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="51"/>
        <source>Charging</source>
        <translation>S&apos;està carregant</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="60"/>
        <source>Lithium ion</source>
        <translation>Ió liti</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="62"/>
        <source>Lithium polymer</source>
        <translation>Ió liti en polímer</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="64"/>
        <source>Lithium iron phosphate</source>
        <translation>Fosfat de ferro i liti</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="66"/>
        <source>Lead acid</source>
        <translation>Plom i àcid</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="68"/>
        <source>Nickel cadmium</source>
        <translation>Níquel i cadmi</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="70"/>
        <source>Nickel metal hydride</source>
        <translation>Hidrur metàl·lic de níquel</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="73"/>
        <source>Unknown</source>
        <translation>Desconeguda</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="82"/>
        <source>Personal Digital Assistant&apos;s battery</source>
        <translation>Bateria d&apos;ordinador de butxaca</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="84"/>
        <source>Uninterruptible Power Supply&apos;s battery</source>
        <translation>Bateria de sistema d&apos;alimentació ininterrompuda</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="86"/>
        <source>Primary battery</source>
        <translation>Bateria primària</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="88"/>
        <source>Mouse battery</source>
        <translation>Bateria de ratolí</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="90"/>
        <source>Keyboard battery</source>
        <translation>Bateria de teclat</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="92"/>
        <source>Keyboard and mouse&apos;s battery</source>
        <translation>Bateria de teclat i ratolí</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="94"/>
        <source>Camera battery</source>
        <translation>Bateria de càmera</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="96"/>
        <source>Phone battery</source>
        <translation>Bateria de telèfon</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="98"/>
        <source>Monitor battery</source>
        <translation>Bateria de monitor</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="101"/>
        <source>Unknown battery</source>
        <translation>Bateria desconeguda</translation>
    </message>
    <message numerus="yes">
        <location filename="../batteryhelper.cpp" line="111"/>
        <source>%Ln hour(s)</source>
        <translation>
            <numerusform>%Ln hora</numerusform>
            <numerusform>%Ln hores%</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../batteryhelper.cpp" line="112"/>
        <source>%Ln minute(s)</source>
        <translation>
            <numerusform>%Ln minut</numerusform>
            <numerusform>%Ln minuts</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="117"/>
        <source>remaining %1</source>
        <translation>%1 restant</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="122"/>
        <source>to full %1</source>
        <translation>%1 per a càrrega completa</translation>
    </message>
</context>
<context>
    <name>BatteryInfoDialog</name>
    <message>
        <location filename="../batteryinfodialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Diàleg</translation>
    </message>
    <message>
        <location filename="../batteryinfodialog.cpp" line="24"/>
        <source>Battery Info</source>
        <translation>Informació de la bateria</translation>
    </message>
</context>
<context>
    <name>BatteryInfoFrame</name>
    <message>
        <location filename="../batteryinfoframe.ui" line="14"/>
        <source>Power Management</source>
        <translation>Gestió de l&apos;energia</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="53"/>
        <source>Temperature:</source>
        <translation>Temperatura:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="63"/>
        <source>Type:</source>
        <translation>Tipus:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="73"/>
        <source>State:</source>
        <translation>Estat:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="90"/>
        <source>Energy Full Design:</source>
        <translation>Energia disseny-producció:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="107"/>
        <source>Energy Full:</source>
        <translation>Energia plena:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="124"/>
        <source>Energy Now:</source>
        <translation>Energia ara:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="141"/>
        <source>Energy rate:</source>
        <translation>Cadència d&apos;energia:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="165"/>
        <source>Technology:</source>
        <translation>Tecnologia:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="182"/>
        <source>Voltage:</source>
        <translation>Voltatge:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="192"/>
        <source>Vendor:</source>
        <translation>Fabricant:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.cpp" line="65"/>
        <source>Empty</source>
        <translation>Buit</translation>
    </message>
</context>
<context>
    <name>BatteryWatcher</name>
    <message>
        <location filename="../batterywatcher.cpp" line="48"/>
        <source>No battery!</source>
        <translation>Sense bateria!</translation>
    </message>
    <message>
        <location filename="../batterywatcher.cpp" line="49"/>
        <source>LXQt could not find data about any battery - monitoring disabled</source>
        <translation>LXQt no ha pogut trobar les dades de cap bateria - s&apos;ha inhabilitat el monitoratge</translation>
    </message>
    <message>
        <location filename="../batterywatcher.cpp" line="119"/>
        <source>Power low!</source>
        <translation>Energia baixa!</translation>
    </message>
    <message numerus="yes">
        <location filename="../batterywatcher.cpp" line="131"/>
        <source>Suspending in %Ln second(s)</source>
        <translation>
            <numerusform>Suspenent en %Ln segon</numerusform>
            <numerusform>Suspenent en %Ln segons</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../batterywatcher.cpp" line="134"/>
        <source>Hibernating in %Ln second(s)</source>
        <translation>
            <numerusform>Hibernació en %Ln segon</numerusform>
            <numerusform>Hibernació en %Ln segons</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../batterywatcher.cpp" line="137"/>
        <source>Shutting down in %Ln second(s)</source>
        <translation>
            <numerusform>S&apos;aturarà en %Ln segon</numerusform>
            <numerusform>S&apos;aturarà en %Ln segons</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>PowerButton</name>
    <message>
        <location filename="../powerbutton.cpp" line="72"/>
        <source>Power off key action</source>
        <translation>Acció del botó d&apos;aturada</translation>
    </message>
    <message>
        <location filename="../powerbutton.cpp" line="79"/>
        <source>Suspend key action</source>
        <translation>Acció del botó de suspensió</translation>
    </message>
    <message>
        <location filename="../powerbutton.cpp" line="86"/>
        <source>Hibernate key action</source>
        <translation>Acció del botó d&apos;hibernació</translation>
    </message>
</context>
<context>
    <name>PowerManagementd</name>
    <message>
        <location filename="../powermanagementd.cpp" line="115"/>
        <source>Power Management</source>
        <translation>Gestió de l&apos;energia</translation>
    </message>
    <message>
        <location filename="../powermanagementd.cpp" line="116"/>
        <source>You are running LXQt Power Management for the first time.
You can configure it from settings... </source>
        <translation>Esteu executant per primera vegada la gestió de l&apos;energia de LXQt.
Podeu configurar-ho des dels ajusts... </translation>
    </message>
    <message>
        <location filename="../powermanagementd.cpp" line="117"/>
        <source>Configure...</source>
        <translation>Configura...</translation>
    </message>
</context>
<context>
    <name>TrayIcon</name>
    <message>
        <location filename="../trayicon.cpp" line="68"/>
        <source>Configure</source>
        <translation>Configura</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="76"/>
        <source>30 minutes</source>
        <translation>30 minuts</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="80"/>
        <source>1 hour</source>
        <translation>1 hora</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="84"/>
        <source>2 hours</source>
        <translation>2 hores</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="88"/>
        <source>3 hours</source>
        <translation>3 hores</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="92"/>
        <source>4 hours</source>
        <translation>4 hores</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="97"/>
        <source>Pause idleness checks</source>
        <translation>Pausa les comprovacions d&apos;inactivitat</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="102"/>
        <location filename="../trayicon.cpp" line="194"/>
        <source>About</source>
        <translation>Quant a</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="104"/>
        <source>Disable icon</source>
        <translation>Inhabilita la icona</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="163"/>
        <source>Empty</source>
        <translation>Buit</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="195"/>
        <source>&lt;p&gt;  &lt;b&gt;LXQt Power Management&lt;/b&gt;&lt;br/&gt;  - Power Management for the LXQt Desktop Environment&lt;/p&gt;&lt;p&gt;  Authors:&lt;br/&gt;  &amp;nbsp; Christian Surlykke, Alec Moskvin&lt;br/&gt;  &amp;nbsp; - and others from the Razor and LXQt projects&lt;/p&gt;&lt;p&gt;  Copyright &amp;copy; 2012-2014&lt;/p&gt;</source>
        <translation>&lt;p&gt;  &lt;b&gt;Gestió de l&apos;energia de LXQt&lt;/b&gt;&lt;br/&gt;  - Gestió de l&apos;energia per a l&apos;entorn d&apos;escriptori LXQt&lt;/p&gt;&lt;p&gt;  Autors:&lt;br/&gt;  &amp;nbsp; Christian Surlykke, Alec Moskvin&lt;br/&gt;  &amp;nbsp; - i altres des dels projectes Razor i LXQt&lt;/p&gt;&lt;p&gt;  Copyright &amp;copy; 2012-2014&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="213"/>
        <source>LXQt Power Management info</source>
        <translation>Informació de la gestió de l&apos;energia de LXQt</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="214"/>
        <source>The LXQt Power Management tray icon can be (re)enabled in &lt;i&gt;lxqt-config-powermanagement&lt;/i&gt;</source>
        <translation>La icona de la safata de la gestió de l&apos;energia de LXQt pot ser (re)habilitada a &lt;i&gt;lxqt-config-powermanagement&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="216"/>
        <source>Configure now</source>
        <translation>Configura ara</translation>
    </message>
</context>
</TS>

==> 2.2.1.tar.gz: lxqt-powermanagement-2.2.1/src/translations/lxqt-powermanagement_ca.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>BatteryHelper</name>
    <message>
        <location filename="../batteryhelper.cpp" line="44"/>
        <source>Stable</source>
        <translation>Estable</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="46"/>
        <source>Discharging</source>
        <translation>S&apos;està descarregant</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="48"/>
        <source>Fully charged</source>
        <translation>Completament carregada</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="51"/>
        <source>Charging</source>
        <translation>S&apos;està carregant</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="60"/>
        <source>Lithium ion</source>
        <translation>Ió liti</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="62"/>
        <source>Lithium polymer</source>
        <translation>Ió liti en polímer</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="64"/>
        <source>Lithium iron phosphate</source>
        <translation>Fosfat de ferro i liti</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="66"/>
        <source>Lead acid</source>
        <translation>Plom i àcid</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="68"/>
        <source>Nickel cadmium</source>
        <translation>Níquel i cadmi</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="70"/>
        <source>Nickel metal hydride</source>
        <translation>Hidrur metàl·lic de níquel</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="73"/>
        <source>Unknown</source>
        <translation>Desconeguda</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="82"/>
        <source>Personal Digital Assistant&apos;s battery</source>
        <translation>Bateria d&apos;ordinador de butxaca</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="84"/>
        <source>Uninterruptible Power Supply&apos;s battery</source>
        <translation>Bateria de sistema d&apos;alimentació ininterrompuda</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="86"/>
        <source>Primary battery</source>
        <translation>Bateria primària</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="88"/>
        <source>Mouse battery</source>
        <translation>Bateria de ratolí</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="90"/>
        <source>Keyboard battery</source>
        <translation>Bateria de teclat</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="92"/>
        <source>Keyboard and mouse&apos;s battery</source>
        <translation>Bateria de teclat i ratolí</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="94"/>
        <source>Camera battery</source>
        <translation>Bateria de càmera</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="96"/>
        <source>Phone battery</source>
        <translation>Bateria de telèfon</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="98"/>
        <source>Monitor battery</source>
        <translation>Bateria de monitor</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="101"/>
        <source>Unknown battery</source>
        <translation>Bateria desconeguda</translation>
    </message>
    <message numerus="yes">
        <location filename="../batteryhelper.cpp" line="111"/>
        <source>%Ln hour(s)</source>
        <translation>
            <numerusform>%Ln hora</numerusform>
            <numerusform>%Ln hores%</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../batteryhelper.cpp" line="112"/>
        <source>%Ln minute(s)</source>
        <translation>
            <numerusform>%Ln minut</numerusform>
            <numerusform>%Ln minuts</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="117"/>
        <source>remaining %1</source>
        <translation>%1 restant</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="122"/>
        <source>to full %1</source>
        <translation>%1 per a càrrega completa</translation>
    </message>
</context>
<context>
    <name>BatteryInfoDialog</name>
    <message>
        <location filename="../batteryinfodialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Diàleg</translation>
    </message>
    <message>
        <location filename="../batteryinfodialog.cpp" line="24"/>
        <source>Battery Info</source>
        <translation>Informació de la bateria</translation>
    </message>
</context>
<context>
    <name>BatteryInfoFrame</name>
    <message>
        <location filename="../batteryinfoframe.ui" line="14"/>
        <source>Power Management</source>
        <translation>Gestió de l&apos;energia</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="53"/>
        <source>Temperature:</source>
        <translation>Temperatura:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="63"/>
        <source>Type:</source>
        <translation>Tipus:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="73"/>
        <source>State:</source>
        <translation>Estat:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="90"/>
        <source>Energy Full Design:</source>
        <translation>Energia disseny-producció:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="107"/>
        <source>Energy Full:</source>
        <translation>Energia plena:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="124"/>
        <source>Energy Now:</source>
        <translation>Energia ara:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="141"/>
        <source>Energy rate:</source>
        <translation>Cadència d&apos;energia:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="165"/>
        <source>Technology:</source>
        <translation>Tecnologia:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="182"/>
        <source>Voltage:</source>
        <translation>Voltatge:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="192"/>
        <source>Vendor:</source>
        <translation>Fabricant:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.cpp" line="65"/>
        <source>Empty</source>
        <translation>Buit</translation>
    </message>
</context>
<context>
    <name>BatteryWatcher</name>
    <message>
        <location filename="../batterywatcher.cpp" line="48"/>
        <source>No battery!</source>
        <translation>Sense bateria!</translation>
    </message>
    <message>
        <location filename="../batterywatcher.cpp" line="49"/>
        <source>LXQt could not find data about any battery - monitoring disabled</source>
        <translation>LXQt no ha pogut trobar les dades de cap bateria - s&apos;ha inhabilitat el monitoratge</translation>
    </message>
    <message>
        <location filename="../batterywatcher.cpp" line="119"/>
        <source>Power low!</source>
        <translation>Energia baixa!</translation>
    </message>
    <message numerus="yes">
        <location filename="../batterywatcher.cpp" line="131"/>
        <source>Suspending in %Ln second(s)</source>
        <translation>
            <numerusform>Suspenent en %Ln segon</numerusform>
            <numerusform>Suspenent en %Ln segons</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../batterywatcher.cpp" line="134"/>
        <source>Hibernating in %Ln second(s)</source>
        <translation>
            <numerusform>Hibernació en %Ln segon</numerusform>
            <numerusform>Hibernació en %Ln segons</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../batterywatcher.cpp" line="137"/>
        <source>Shutting down in %Ln second(s)</source>
        <translation>
            <numerusform>S&apos;aturarà en %Ln segon</numerusform>
            <numerusform>S&apos;aturarà en %Ln segons</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>LXQt::PowerProfiles</name>
    <message>
        <location filename="../PowerProfiles.cpp" line="38"/>
        <source>power-saver</source>
        <comment>power-profiles-daemon</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../PowerProfiles.cpp" line="39"/>
        <source>balanced</source>
        <comment>power-profiles-daemon</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../PowerProfiles.cpp" line="40"/>
        <source>performance</source>
        <comment>power-profiles-daemon</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../PowerProfiles.cpp" line="69"/>
        <source>Power profile</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PowerButton</name>
    <message>
        <location filename="../powerbutton.cpp" line="72"/>
        <source>Power off key action</source>
        <translation>Acció del botó d&apos;aturada</translation>
    </message>
    <message>
        <location filename="../powerbutton.cpp" line="79"/>
        <source>Suspend key action</source>
        <translation>Acció del botó de suspensió</translation>
    </message>
    <message>
        <location filename="../powerbutton.cpp" line="86"/>
        <source>Hibernate key action</source>
        <translation>Acció del botó d&apos;hibernació</translation>
    </message>
</context>
<context>
    <name>PowerManagementd</name>
    <message>
        <location filename="../powermanagementd.cpp" line="115"/>
        <source>Power Management</source>
        <translation>Gestió de l&apos;energia</translation>
    </message>
    <message>
        <location filename="../powermanagementd.cpp" line="116"/>
        <source>You are running LXQt Power Management for the first time.
You can configure it from settings... </source>
        <translation>Esteu executant per primera vegada la gestió de l&apos;energia de LXQt.
Podeu configurar-ho des dels ajusts... </translation>
    </message>
    <message>
        <location filename="../powermanagementd.cpp" line="117"/>
        <source>Configure...</source>
        <translation>Configura...</translation>
    </message>
</context>
<context>
    <name>TrayIcon</name>
    <message>
        <location filename="../trayicon.cpp" line="70"/>
        <source>Configure</source>
        <translation>Configura</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="78"/>
        <source>30 minutes</source>
        <translation>30 minuts</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="82"/>
        <source>1 hour</source>
        <translation>1 hora</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="86"/>
        <source>2 hours</source>
        <translation>2 hores</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="90"/>
        <source>3 hours</source>
        <translation>3 hores</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="94"/>
        <source>4 hours</source>
        <translation>4 hores</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="99"/>
        <source>Pause idleness checks</source>
        <translation>Pausa les comprovacions d&apos;inactivitat</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="107"/>
        <location filename="../trayicon.cpp" line="199"/>
        <source>About</source>
        <translation>Quant a</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="109"/>
        <source>Disable icon</source>
        <translation>Inhabilita la icona</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="168"/>
        <source>Empty</source>
        <translation>Buit</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="200"/>
        <source>&lt;p&gt;  &lt;b&gt;LXQt Power Management&lt;/b&gt;&lt;br/&gt;  - Power Management for the LXQt Desktop Environment&lt;/p&gt;&lt;p&gt;  Authors:&lt;br/&gt;  &amp;nbsp; Christian Surlykke, Alec Moskvin&lt;br/&gt;  &amp;nbsp; - and others from the Razor and LXQt projects&lt;/p&gt;&lt;p&gt;  Copyright &amp;copy; 2012-2025&lt;/p&gt;</source>
        <translation>&lt;p&gt;  &lt;b&gt;Gestió de l&apos;energia de LXQt&lt;/b&gt;&lt;br/&gt;  - Gestió de l&apos;energia per a l&apos;entorn d&apos;escriptori LXQt&lt;/p&gt;&lt;p&gt;  Autors:&lt;br/&gt;  &amp;nbsp; Christian Surlykke, Alec Moskvin&lt;br/&gt;  &amp;nbsp; - i altres des dels projectes Razor i LXQt&lt;/p&gt;&lt;p&gt;  Copyright &amp;copy; 2012-2025&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="218"/>
        <source>LXQt Power Management info</source>
        <translation>Informació de la gestió de l&apos;energia de LXQt</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="219"/>
        <source>The LXQt Power Management tray icon can be (re)enabled in &lt;i&gt;lxqt-config-powermanagement&lt;/i&gt;</source>
        <translation>La icona de la safata de la gestió de l&apos;energia de LXQt pot ser (re)habilitada a &lt;i&gt;lxqt-config-powermanagement&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="221"/>
        <source>Configure now</source>
        <translation>Configura ara</translation>
    </message>
</context>
</TS>
